summaryrefslogtreecommitdiff
path: root/searx/plugins
diff options
context:
space:
mode:
Diffstat (limited to 'searx/plugins')
-rw-r--r--searx/plugins/self_ip.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/searx/plugins/self_ip.py b/searx/plugins/self_ip.py
index 31c80f91e..ab9c732ec 100644
--- a/searx/plugins/self_ip.py
+++ b/searx/plugins/self_ip.py
@@ -4,10 +4,10 @@ description = gettext('Display your source IP address if the query expression is
default_on = True
# attach callback to the pre search hook
# request: flask request object
# ctx: the whole local context of the pre search hook
-def pre_search(request, ctx):
+def post_search(request, ctx):
if ctx['search'].query == 'ip':
x_forwarded_for = request.headers.getlist("X-Forwarded-For")
if x_forwarded_for:
@@ -4,10 +4,10 @@ description = gettext('Display your source IP address if the query expression is
default_on = True
-# attach callback to the pre search hook
+# attach callback to the post search hook
# request: flask request object
# ctx: the whole local context of the pre search hook